# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.121.0-v202603310002-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class AgentOrchestratorOutputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _agent_provisioning_expiration_at: Optional[str]
    _agent_provisioning_requested_at: Optional[str]
    _agent_provisioning_status: Optional[str]
    _name: str


    def __init__(
        self,
        agent_provisioning_expiration_at: Optional[str] = None,
        agent_provisioning_requested_at: Optional[str] = None,
        agent_provisioning_status: Optional[str] = None,
        name: Optional[str] = None,
    ) -> None: ...

    @property
    def agent_provisioning_expiration_at(self) -> Optional[str]: ...

    @agent_provisioning_expiration_at.setter
    def agent_provisioning_expiration_at(self, agent_provisioning_expiration_at: Optional[str]) -> None: ...

    @property
    def agent_provisioning_requested_at(self) -> Optional[str]: ...

    @agent_provisioning_requested_at.setter
    def agent_provisioning_requested_at(self, agent_provisioning_requested_at: Optional[str]) -> None: ...

    @property
    def agent_provisioning_status(self) -> Optional[str]: ...

    @agent_provisioning_status.setter
    def agent_provisioning_status(self, agent_provisioning_status: Optional[str]) -> None: ...

    @property
    def name(self) -> str: ...

    @name.setter
    def name(self, name: str) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.121.0-v202603310002-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class FormulaParameterOutputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _formula: Optional[str]
    _item: Optional[ItemSearchPreviewV1]
    _name: str
    _unbound: Optional[bool]


    def __init__(
        self,
        formula: Optional[str] = None,
        item: Optional[ItemSearchPreviewV1] = None,
        name: Optional[str] = None,
        unbound: Optional[bool] = False,
    ) -> None: ...

    @property
    def formula(self) -> Optional[str]: ...

    @formula.setter
    def formula(self, formula: Optional[str]) -> None: ...

    @property
    def item(self) -> Optional[ItemSearchPreviewV1]: ...

    @item.setter
    def item(self, item: Optional[ItemSearchPreviewV1]) -> None: ...

    @property
    def name(self) -> str: ...

    @name.setter
    def name(self, name: str) -> None: ...

    @property
    def unbound(self) -> Optional[bool]: ...

    @unbound.setter
    def unbound(self, unbound: Optional[bool]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.121.0-v202603310002-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class CapsuleV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _cursor_key: Optional[Any]
    _end: Optional[Any]
    _id: str
    _is_uncertain: Optional[bool]
    _properties: Optional[List[ScalarPropertyV1]]
    _start: Any


    def __init__(
        self,
        cursor_key: Optional[Any] = None,
        end: Optional[Any] = None,
        id: Optional[str] = None,
        is_uncertain: Optional[bool] = None,
        properties: Optional[List[ScalarPropertyV1]] = None,
        start: Optional[Any] = None,
    ) -> None: ...

    @property
    def cursor_key(self) -> Optional[Any]: ...

    @cursor_key.setter
    def cursor_key(self, cursor_key: Optional[Any]) -> None: ...

    @property
    def end(self) -> Optional[Any]: ...

    @end.setter
    def end(self, end: Optional[Any]) -> None: ...

    @property
    def id(self) -> str: ...

    @id.setter
    def id(self, id: str) -> None: ...

    @property
    def is_uncertain(self) -> Optional[bool]: ...

    @is_uncertain.setter
    def is_uncertain(self, is_uncertain: Optional[bool]) -> None: ...

    @property
    def properties(self) -> Optional[List[ScalarPropertyV1]]: ...

    @properties.setter
    def properties(self, properties: Optional[List[ScalarPropertyV1]]) -> None: ...

    @property
    def start(self) -> Any: ...

    @start.setter
    def start(self, start: Any) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.121.0-v202603310002-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class StoredTableSearchFailureOutputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _message_key: str
    _row_id: str
    _search_string: str
    _stored_table_id: str


    def __init__(
        self,
        message_key: Optional[str] = None,
        row_id: Optional[str] = None,
        search_string: Optional[str] = None,
        stored_table_id: Optional[str] = None,
    ) -> None: ...

    @property
    def message_key(self) -> str: ...

    @message_key.setter
    def message_key(self, message_key: str) -> None: ...

    @property
    def row_id(self) -> str: ...

    @row_id.setter
    def row_id(self, row_id: str) -> None: ...

    @property
    def search_string(self) -> str: ...

    @search_string.setter
    def search_string(self, search_string: str) -> None: ...

    @property
    def stored_table_id(self) -> str: ...

    @stored_table_id.setter
    def stored_table_id(self, stored_table_id: str) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.121.0-v202603310002-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class ManualRunInputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _condition_id: str
    _look_ahead_duration_seconds: Optional[int]
    _lookback_duration_seconds: int
    _table_batch_action: Optional[str]


    def __init__(
        self,
        condition_id: Optional[str] = None,
        look_ahead_duration_seconds: Optional[int] = None,
        lookback_duration_seconds: Optional[int] = None,
        table_batch_action: Optional[str] = None,
    ) -> None: ...

    @property
    def condition_id(self) -> str: ...

    @condition_id.setter
    def condition_id(self, condition_id: str) -> None: ...

    @property
    def look_ahead_duration_seconds(self) -> Optional[int]: ...

    @look_ahead_duration_seconds.setter
    def look_ahead_duration_seconds(self, look_ahead_duration_seconds: Optional[int]) -> None: ...

    @property
    def lookback_duration_seconds(self) -> int: ...

    @lookback_duration_seconds.setter
    def lookback_duration_seconds(self, lookback_duration_seconds: int) -> None: ...

    @property
    def table_batch_action(self) -> Optional[str]: ...

    @table_batch_action.setter
    def table_batch_action(self, table_batch_action: Optional[str]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.121.0-v202603310002-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class CustomAgentVersionOutputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'production': 'bool',
        'revision': 'CustomAgentRevisionOutputV1',
        'version': 'int'
    }

    attribute_map = {
        'production': 'production',
        'revision': 'revision',
        'version': 'version'
    }

    def __init__(self, production=None, revision=None, version=None):
        """
        CustomAgentVersionOutputV1 - a model defined in Swagger
        """

        self._production = None
        self._revision = None
        self._version = None

        if production is not None:
          self.production = production
        if revision is not None:
          self.revision = revision
        if version is not None:
          self.version = version

    @property
    def production(self):
        """
        Gets the production of this CustomAgentVersionOutputV1.
        Whether this is the production version

        :return: The production of this CustomAgentVersionOutputV1.
        :rtype: bool
        """
        return self._production

    @production.setter
    def production(self, production):
        """
        Sets the production of this CustomAgentVersionOutputV1.
        Whether this is the production version

        :param production: The production of this CustomAgentVersionOutputV1.
        :type: bool
        """
        if production is None:
            raise ValueError("Invalid value for `production`, must not be `None`")

        self._production = production

    @property
    def revision(self):
        """
        Gets the revision of this CustomAgentVersionOutputV1.

        :return: The revision of this CustomAgentVersionOutputV1.
        :rtype: CustomAgentRevisionOutputV1
        """
        return self._revision

    @revision.setter
    def revision(self, revision):
        """
        Sets the revision of this CustomAgentVersionOutputV1.

        :param revision: The revision of this CustomAgentVersionOutputV1.
        :type: CustomAgentRevisionOutputV1
        """
        if revision is None:
            raise ValueError("Invalid value for `revision`, must not be `None`")

        self._revision = revision

    @property
    def version(self):
        """
        Gets the version of this CustomAgentVersionOutputV1.
        The version number

        :return: The version of this CustomAgentVersionOutputV1.
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """
        Sets the version of this CustomAgentVersionOutputV1.
        The version number

        :param version: The version of this CustomAgentVersionOutputV1.
        :type: int
        """
        if version is None:
            raise ValueError("Invalid value for `version`, must not be `None`")

        self._version = version

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, CustomAgentVersionOutputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.121.0-v202603310002-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class IdentityPreviewV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _datasource: Optional[DatasourcePreviewV1]
    _email: Optional[str]
    _id: str
    _is_archived: Optional[bool]
    _is_enabled: Optional[bool]
    _is_organization_group: Optional[bool]
    _is_redacted: Optional[bool]
    _is_remote_group_editable: Optional[bool]
    _name: str
    _organization_group: Optional[bool]
    _remote_group_editable: Optional[bool]
    _translation_key: Optional[str]
    _type: str
    _username: Optional[str]
    _username_readable: Optional[bool]


    def __init__(
        self,
        datasource: Optional[DatasourcePreviewV1] = None,
        email: Optional[str] = None,
        id: Optional[str] = None,
        is_archived: Optional[bool] = False,
        is_enabled: Optional[bool] = False,
        is_organization_group: Optional[bool] = False,
        is_redacted: Optional[bool] = False,
        is_remote_group_editable: Optional[bool] = False,
        name: Optional[str] = None,
        organization_group: Optional[bool] = None,
        remote_group_editable: Optional[bool] = None,
        translation_key: Optional[str] = None,
        type: Optional[str] = None,
        username: Optional[str] = None,
        username_readable: Optional[bool] = False,
    ) -> None: ...

    @property
    def datasource(self) -> Optional[DatasourcePreviewV1]: ...

    @datasource.setter
    def datasource(self, datasource: Optional[DatasourcePreviewV1]) -> None: ...

    @property
    def email(self) -> Optional[str]: ...

    @email.setter
    def email(self, email: Optional[str]) -> None: ...

    @property
    def id(self) -> str: ...

    @id.setter
    def id(self, id: str) -> None: ...

    @property
    def is_archived(self) -> Optional[bool]: ...

    @is_archived.setter
    def is_archived(self, is_archived: Optional[bool]) -> None: ...

    @property
    def is_enabled(self) -> Optional[bool]: ...

    @is_enabled.setter
    def is_enabled(self, is_enabled: Optional[bool]) -> None: ...

    @property
    def is_organization_group(self) -> Optional[bool]: ...

    @is_organization_group.setter
    def is_organization_group(self, is_organization_group: Optional[bool]) -> None: ...

    @property
    def is_redacted(self) -> Optional[bool]: ...

    @is_redacted.setter
    def is_redacted(self, is_redacted: Optional[bool]) -> None: ...

    @property
    def is_remote_group_editable(self) -> Optional[bool]: ...

    @is_remote_group_editable.setter
    def is_remote_group_editable(self, is_remote_group_editable: Optional[bool]) -> None: ...

    @property
    def name(self) -> str: ...

    @name.setter
    def name(self, name: str) -> None: ...

    @property
    def organization_group(self) -> Optional[bool]: ...

    @organization_group.setter
    def organization_group(self, organization_group: Optional[bool]) -> None: ...

    @property
    def remote_group_editable(self) -> Optional[bool]: ...

    @remote_group_editable.setter
    def remote_group_editable(self, remote_group_editable: Optional[bool]) -> None: ...

    @property
    def translation_key(self) -> Optional[str]: ...

    @translation_key.setter
    def translation_key(self, translation_key: Optional[str]) -> None: ...

    @property
    def type(self) -> str: ...

    @type.setter
    def type(self, type: str) -> None: ...

    @property
    def username(self) -> Optional[str]: ...

    @username.setter
    def username(self, username: Optional[str]) -> None: ...

    @property
    def username_readable(self) -> Optional[bool]: ...

    @username_readable.setter
    def username_readable(self, username_readable: Optional[bool]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.121.0-v202603310002-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class LabelHierarchyOutputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _category_id: str
    _category_name: str
    _children: List[LabelHierarchyOutputV1]
    _label_id: str
    _label_name: str


    def __init__(
        self,
        category_id: Optional[str] = None,
        category_name: Optional[str] = None,
        children: Optional[List[LabelHierarchyOutputV1]] = None,
        label_id: Optional[str] = None,
        label_name: Optional[str] = None,
    ) -> None: ...

    @property
    def category_id(self) -> str: ...

    @category_id.setter
    def category_id(self, category_id: str) -> None: ...

    @property
    def category_name(self) -> str: ...

    @category_name.setter
    def category_name(self, category_name: str) -> None: ...

    @property
    def children(self) -> List[LabelHierarchyOutputV1]: ...

    @children.setter
    def children(self, children: List[LabelHierarchyOutputV1]) -> None: ...

    @property
    def label_id(self) -> str: ...

    @label_id.setter
    def label_id(self, label_id: str) -> None: ...

    @property
    def label_name(self) -> str: ...

    @label_name.setter
    def label_name(self, label_name: str) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.121.0-v202603310002-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class SubscriptionInputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'channel_id': 'str',
        'subscriber_parameters': 'dict(str, str)'
    }

    attribute_map = {
        'channel_id': 'channelId',
        'subscriber_parameters': 'subscriberParameters'
    }

    def __init__(self, channel_id=None, subscriber_parameters=None):
        """
        SubscriptionInputV1 - a model defined in Swagger
        """

        self._channel_id = None
        self._subscriber_parameters = None

        if channel_id is not None:
          self.channel_id = channel_id
        if subscriber_parameters is not None:
          self.subscriber_parameters = subscriber_parameters

    @property
    def channel_id(self):
        """
        Gets the channel_id of this SubscriptionInputV1.
        URI that uniquely identifies the channel

        :return: The channel_id of this SubscriptionInputV1.
        :rtype: str
        """
        return self._channel_id

    @channel_id.setter
    def channel_id(self, channel_id):
        """
        Sets the channel_id of this SubscriptionInputV1.
        URI that uniquely identifies the channel

        :param channel_id: The channel_id of this SubscriptionInputV1.
        :type: str
        """
        if channel_id is None:
            raise ValueError("Invalid value for `channel_id`, must not be `None`")

        self._channel_id = channel_id

    @property
    def subscriber_parameters(self):
        """
        Gets the subscriber_parameters of this SubscriptionInputV1.
        Parameters associated with the subscriber

        :return: The subscriber_parameters of this SubscriptionInputV1.
        :rtype: dict(str, str)
        """
        return self._subscriber_parameters

    @subscriber_parameters.setter
    def subscriber_parameters(self, subscriber_parameters):
        """
        Sets the subscriber_parameters of this SubscriptionInputV1.
        Parameters associated with the subscriber

        :param subscriber_parameters: The subscriber_parameters of this SubscriptionInputV1.
        :type: dict(str, str)
        """

        self._subscriber_parameters = subscriber_parameters

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, SubscriptionInputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
